function [Unew,Fnew] = PerfScr(U,p,s)
% function [Unew,Fnew] = PerfScr(U,p,s)
% Performs one screening round: updates U and return findings
% INPUT  size
%   U    (xm,1)  State pdf at the screening age
%   p    (1,1)   Attendance probability now
%   s    (xm,1)  Screening sensitivities against X(j)
% OUTPUT size
%   Unew (xm,1)  Updated pdf
%   Fnew (xm,1)  Findings done by screening

Uatt = p*U; % Attenders
Unatt = (1-p)*U; % Non-attenders
 
Fnew = s.*Uatt; % Findings from attenders by stage

UattNEW = (1-s).*Uatt; % Not diagnosed from attenders
UattNEW(1) = UattNEW(1) + sum(Fnew); % All findings added to S
  
% Non-attenders and attenders combined:
Unew = Unatt + UattNEW;
 